import com.silanis.esl.sdk.DocumentPackage;
import com.silanis.esl.sdk.DocumentType;
import com.silanis.esl.sdk.EslClient;
import com.silanis.esl.sdk.PackageId;
import com.silanis.esl.sdk.PageRequest;
import com.silanis.esl.sdk.Sender;
import com.silanis.esl.sdk.SenderInfo;
import com.silanis.esl.sdk.SenderStatus;
import com.silanis.esl.sdk.builder.AccountMemberBuilder;
import com.silanis.esl.sdk.builder.DocumentBuilder;
import com.silanis.esl.sdk.builder.PackageBuilder;
import com.silanis.esl.sdk.builder.SenderInfoBuilder;
import com.silanis.esl.sdk.builder.SignerBuilder;
import com.silanis.esl.sdk.AccountMember;
import com.silanis.esl.sdk.Direction;

import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.util.Map;

public class sendersBlog {
	
	//replace api_key placeholder with your own value
	private static String API_KEY = "api_key";
	private static String API_URL = "https://sandbox.e-signlive.com/api";
	
	public static void main(String[] args) throws FileNotFoundException {
		
		EslClient client = new EslClient(API_KEY, API_URL);
		
		/*--------------------------------Invite member to be a sender------------------------------*/
		
		AccountMember member = AccountMemberBuilder.newAccountMember("esl.signer1@example.com")
				.withFirstName("John")
				.withLastName("Smith")
				.withCompany("Bank of America")
				.withTitle("CEO")
				.withStatus(SenderStatus.ACTIVE)
				.build();
		
		client.getAccountService().inviteUser(member);
		
		/*------------------------Retrieve list of senders in your account---------------------------------*/
		
		int i = 1;
		Map<String, Sender> accountMembers = client.getAccountService().getSenders(Direction.ASCENDING, new PageRequest(i,5));
		
		while (!accountMembers.isEmpty()) {
			for (Map.Entry<String, Sender> entry : accountMembers.entrySet())
			{
				System.out.println(entry.getKey() + " / " + entry.getValue().getId());
				i++;
			}
			accountMembers = client.getAccountService().getSenders(Direction.ASCENDING, new PageRequest(i,5));
		}
		
		/*--------------------------------Update sender info------------------------------------------------*/
		
		SenderInfo updatedSenderInfo = SenderInfoBuilder.newSenderInfo("esl.signer1@example.com")
                .withName( "John", "Smith" )
                .withTitle( "CEO" )
                .withCompany("Bank of America")
                .build();
 
		client.getAccountService().updateSender(updatedSenderInfo, "T3AY60Ev33o0");
		
		/*--------------------------------Delete sender-----------------------------------------*/
		
		client.getAccountService().deleteSender("ITFmsuvhpQM3");
		
		/*--------------------------------Retrieve sender----------------------------------------*/
		
		Sender retrievedSender = client.getAccountService().getSender("T3AY60Ev33o0");
		
		/*---------------------------------Send package from your sender--------------------------------*/
		
		DocumentPackage packageToSend = PackageBuilder.newPackageNamed("Cleaning Contract Example")
				.withSenderInfo(SenderInfoBuilder.newSenderInfo("esl.signer1@example.com"))
				.withSigner(SignerBuilder.newSignerWithEmail("esl.signer2@example.com")
						.withFirstName("Mary")
						.withLastName("Doe #1")
						.withCustomId("client"))
				.withSigner(SignerBuilder.newSignerWithEmail("esl.signer2@example.com")
						.withFirstName("John")
						.withLastName("Smith")
						.withCustomId("contractor"))
				.withDocument(DocumentBuilder.newDocumentWithName("Contract.pdf")
						.fromStream(new FileInputStream("doc_file_path"), DocumentType.PDF)
						.enableExtraction())
				.build();
		
		PackageId packageId = client.createPackage(packageToSend);
       
	}

}
